"use strict";
// The MIT License (MIT)
//
// Copyright (c) 2020 The Prometheus Authors
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
Object.defineProperty(exports, "__esModule", { value: true });
const lsp_1 = require("./lsp");
const hybrid_1 = require("./hybrid");
const lsp_2 = require("../client/lsp");
const prometheus_1 = require("../client/prometheus");
function newCompleteStrategy(conf) {
    if (conf === null || conf === void 0 ? void 0 : conf.lsp) {
        const lspConf = conf.lsp;
        if (lspConf.lspClient) {
            return new lsp_1.LSPComplete(lspConf.lspClient);
        }
        if (lspConf.url) {
            return new lsp_1.LSPComplete(new lsp_2.HTTPLSPClient(lspConf.url, lspConf.httpErrorHandler));
        }
        throw new Error('the url or the lspClient must be set');
    }
    if (conf === null || conf === void 0 ? void 0 : conf.hybrid) {
        const hybridConf = conf.hybrid;
        if (hybridConf.prometheusClient) {
            return new hybrid_1.HybridComplete(hybridConf.prometheusClient);
        }
        if (hybridConf.url) {
            return new hybrid_1.HybridComplete(new prometheus_1.HTTPPrometheusClient(hybridConf.url, hybridConf.httpErrorHandler, hybridConf === null || hybridConf === void 0 ? void 0 : hybridConf.lookbackInterval));
        }
        throw new Error('the url or the prometheusClient must be set');
    }
    return new hybrid_1.HybridComplete();
}
exports.newCompleteStrategy = newCompleteStrategy;
//# sourceMappingURL=index.js.map