"use strict";
// The MIT License (MIT)
//
// Copyright (c) 2020 The Prometheus Authors
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
Object.defineProperty(exports, "__esModule", { value: true });
const lint_1 = require("@codemirror/next/lint");
const lsp_1 = require("./lsp");
const lsp_2 = require("../client/lsp");
const hybrid_1 = require("./hybrid");
function newLintStrategy(conf) {
    if (conf === null || conf === void 0 ? void 0 : conf.lsp) {
        const lspConf = conf.lsp;
        if (lspConf.lspClient) {
            return new lsp_1.LSPLint(lspConf.lspClient);
        }
        if (lspConf.url) {
            return new lsp_1.LSPLint(new lsp_2.HTTPLSPClient(lspConf.url, lspConf.httpErrorHandler));
        }
        throw new Error('the url or the lspClient must be set');
    }
    return new hybrid_1.HybridLint();
}
exports.newLintStrategy = newLintStrategy;
function promQLLinter(callbackFunc, thisArg) {
    return lint_1.linter(callbackFunc.call(thisArg));
}
exports.promQLLinter = promQLLinter;
//# sourceMappingURL=index.js.map