"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// LSPLint will provide a promQL linter based on what the langserver-promql is providing when requested.
class LSPLint {
    constructor(lspClient) {
        this.lspClient = lspClient;
    }
    promQL() {
        return (view) => {
            const state = view.state;
            const expr = state.sliceDoc(0, state.doc.length);
            const body = {
                expr: expr,
                limit: 100,
            };
            return this.lspClient.diagnostic(body).then((items) => {
                const diagnostics = [];
                for (const diag of items) {
                    const lineFrom = state.doc.line(diag.range.start.line + 1);
                    const lineTo = state.doc.line(diag.range.end.line + 1);
                    diagnostics.push({
                        message: diag.message,
                        severity: 'error',
                        from: lineFrom.from + diag.range.start.character,
                        to: lineTo.from + diag.range.end.character,
                    });
                }
                return diagnostics.sort((a, b) => {
                    return a.from - b.from;
                });
            });
        };
    }
}
exports.LSPLint = LSPLint;
//# sourceMappingURL=lsp.js.map